/* RAML Client API calls */
declare var exchange: {
  /**
   * Make an API request to a custom URL.
   *
   * @param {string} url - Provide a url relative to the base URI.
   * @param {any} data - Provide a data object to replace template tags in the url.
   */
  (url: string, data?): {
    delete(body?: any, options?: any, async?: boolean): any,
    head(query?: any, options?: any, async?: boolean): any,
    get(query?: any, options?: any, async?: boolean): any,
    patch(body?: any, options?: any, async?: boolean): any,
    post(body?: any, options?: any, async?: boolean): any,
    put(body?: any, options?: any, async?: boolean): any
  };
  ping: {
    get(query?: any, options?: any, async?: boolean): any;
  };
  health: {
    get(query?: any, options?: any, async?: boolean): any;
  };
  profile: {
    get(query?: any, options?: any, async?: boolean): any;
  };
  files: {
    post(body?: any, options?: any, async?: boolean): any;
  };
  organizations: {
    organizationId(organizationId: string): {
      users: {
        /**
         * Get users for an organization
         *
         * @param {string} search? - Filter results that partially match the input with the asset name
         * @param {number} limit? - Amount of objects retrieved in the response
         * @param {number} offset? - The offset specifies the offset of the first row to return
        */
        get(query?: {
          search: string,
          limit: number,
          offset: number
        }, options?: { proxy: string, beforeSend: () => void, headers: object, body: object, baseUriParameters: object }): any;
      };
      queries: {
        get(query?: any, options?: any, async?: boolean): any;
        post(body?: any, options?: any, async?: boolean): any;
        queryId(queryId: string): {
          patch(body?: any, options?: any, async?: boolean): any;
          delete(body?: any, options?: any, async?: boolean): any;
        };
      };
      assets: {
        groupId(groupId: string): {
          assetId(assetId: string): {
            delete(body?: any, options?: any, async?: boolean): any;
            public: {
              get(query?: any, options?: any, async?: boolean): any;
              put(body?: any, options?: any, async?: boolean): any;
            };
            users: {
              get(query?: any, options?: any, async?: boolean): any;
              put(body?: any, options?: any, async?: boolean): any;
            };
            productApiVersion: {
              productApiVersion(productApiVersion: string): {
                public: {
                  put(body?: any, options?: any, async?: boolean): any;
                  delete(body?: any, options?: any, async?: boolean): any;
                };
                instances: {
                  apiId(apiId: string): {
                    tiers: {
                      get(query?: any, options?: any, async?: boolean): any;
                    };
                  };
                  external: {
                    post(body?: any, options?: any, async?: boolean): any;
                    id(id: string): {
                      patch(body?: any, options?: any, async?: boolean): any;
                      delete(body?: any, options?: any, async?: boolean): any;
                    };
                  };
                  managed: {
                    id(id: string): {
                      patch(body?: any, options?: any, async?: boolean): any;
                    };
                  };
                };
              };
            };
            reviews: {
              search: {
                /**
                 * Search for asset versions reviews
                 *
                 * @param {boolean} includeComments? - Include comments for reviews
                */
                post(query?: {
                  includeComments: boolean
                }, options?: { proxy: string, beforeSend: () => void, headers: object, body: object, baseUriParameters: object }): any;
              };
            };
            version(version: string): {
              patch(body?: any, options?: any, async?: boolean): any;
              delete(body?: any, options?: any, async?: boolean): any;
              metadata: {
                patch(body?: any, options?: any, async?: boolean): any;
              };
              tags: {
                put(body?: any, options?: any, async?: boolean): any;
              };
              api: {
                root: {
                  get(query?: any, options?: any, async?: boolean): any;
                };
                json: {
                  get(query?: any, options?: any, async?: boolean): any;
                };
                filePath(filePath: string): {
                  get(query?: any, options?: any, async?: boolean): any;
                };
              };
              portal: {
                get(query?: any, options?: any, async?: boolean): any;
              };
              pages: {
                get(query?: any, options?: any, async?: boolean): any;
                pagePath(pagePath: string): {
                  get(query?: any, options?: any, async?: boolean): any;
                };
              };
              draft: {
                portal: {
                  get(query?: any, options?: any, async?: boolean): any;
                };
                pages: {
                  post(body?: any, options?: any, async?: boolean): any;
                  get(query?: any, options?: any, async?: boolean): any;
                  pagePath(pagePath: string): {
                    get(query?: any, options?: any, async?: boolean): any;
                    put(body?: any, options?: any, async?: boolean): any;
                    delete(body?: any, options?: any, async?: boolean): any;
                  };
                };
              };
              reviews: {
                /**
                 * Get a list of reviews
                 *
                 * @param {boolean} includeComments? - Indicates to include comments or not in reviews
                */
                get(query?: {
                  includeComments: boolean
                }, options?: { proxy: string, beforeSend: () => void, headers: object, body: object, baseUriParameters: object }): any;
                post(body?: any, options?: any, async?: boolean): any;
                reviewId(reviewId: string): {
                  patch(body?: any, options?: any, async?: boolean): any;
                  delete(body?: any, options?: any, async?: boolean): any;
                  comments: {
                    post(body?: any, options?: any, async?: boolean): any;
                    commentId(commentId: string): {
                      patch(body?: any, options?: any, async?: boolean): any;
                      delete(body?: any, options?: any, async?: boolean): any;
                    };
                  };
                };
              };
              rating: {
                get(query?: any, options?: any, async?: boolean): any;
              };
              status: {
                put(body?: any, options?: any, async?: boolean): any;
              };
            };
          };
        };
      };
      groups: {
        get(query?: any, options?: any, async?: boolean): any;
      };
      projects: {
        projectId(projectId: string): {
          refs: {
            referenceId(referenceId: string): {
              archive: {
                get(query?: any, options?: any, async?: boolean): any;
              };
            };
          };
        };
      };
      applications: {
        /**
         * List of client applications
         *
         * @param {number} includeContractsForApiVersion? - This field is used to filter by API version
         * @param {string} sort? - Property to sort by
         * @param {boolean} ascending? - Order for sorting
         * @param {string} query? - Search criteria
         * @param {number} offset? - The offset specifies the offset of the first row to return.
         * @param {number} limit? - Amount of objects retrieved in the response.
        */
        get(query?: {
          includeContractsForApiVersion: number,
          sort: string,
          ascending: boolean,
          query: string,
          offset: number,
          limit: number
        }, options?: { proxy: string, beforeSend: () => void, headers: object, body: object, baseUriParameters: object }): any;
        post(body?: any, options?: any, async?: boolean): any;
        applicationId(applicationId: string): {
          get(query?: any, options?: any, async?: boolean): any;
          patch(body?: any, options?: any, async?: boolean): any;
          delete(body?: any, options?: any, async?: boolean): any;
          secret: {
            reset: {
              post(body?: any, options?: any, async?: boolean): any;
            };
          };
          contracts: {
            /**
             * Retrieves a list of applications with contracts with the application
             *
             * @param {number} includeContractsForApiVersion? - This field is used to filter by API version
            */
            get(query?: {
              includeContractsForApiVersion: number
            }, options?: { proxy: string, beforeSend: () => void, headers: object, body: object, baseUriParameters: object }): any;
            post(body?: any, options?: any, async?: boolean): any;
            contractId(contractId: string): {
              patch(body?: any, options?: any, async?: boolean): any;
            };
          };
        };
      };
    };
    organizationDomain(organizationDomain: string): {
      assets: {
        /**
         * Get a paginated set of assets
         *
         * @param {string} search - Filter results that partially match the input with the asset name
         * @param {string} type - Filter results that matches the input with the asset type
         * @param {string} domain - Filter results by organization using its domain
         * @param {string} organizationId - Filter results by organizations. For more than one organization, & organizationId=1& organizationId=2, etc...
         * @param {string} runtimeVersion - Filters results by runtime version, allowing partial versions. For example '3.x' will filter in the range [3.0, 4.0)
         * @param {number} offset - The offset specifies the offset of the first row to return
         * @param {number} limit - Amount of objects retrieved in the response
        */
        get(query?: {
          search: string,
          type: string,
          domain: string,
          organizationId: string,
          runtimeVersion: string,
          offset: number,
          limit: number
        }, options?: { proxy: string, beforeSend: () => void, headers: object, body: object, baseUriParameters: object }): any;
        groupId(groupId: string): {
          assetId(assetId: string): {
            get(query?: any, options?: any, async?: boolean): any;
            version(version: string): {
              get(query?: any, options?: any, async?: boolean): any;
            };
            productAPIVersion: {
              productAPIVersion(productAPIVersion: string): {
                get(query?: any, options?: any, async?: boolean): any;
              };
            };
          };
        };
      };
      portal: {
        get(query?: any, options?: any, async?: boolean): any;
        patch(body?: any, options?: any, async?: boolean): any;
        pages: {
          pageName(pageName: string): {
            get(query?: any, options?: any, async?: boolean): any;
          };
        };
        draft: {
          delete(body?: any, options?: any, async?: boolean): any;
          get(query?: any, options?: any, async?: boolean): any;
          put(body?: any, options?: any, async?: boolean): any;
          pages: {
            post(body?: any, options?: any, async?: boolean): any;
            pageName(pageName: string): {
              put(body?: any, options?: any, async?: boolean): any;
              delete(body?: any, options?: any, async?: boolean): any;
              get(query?: any, options?: any, async?: boolean): any;
            };
          };
        };
      };
    };
  };
  assets: {
    /**
     * Upload an asset
     *
     * @param {string} search - Filter results that partially match the input with the asset name
     * @param {string} type - Filter results that matches the input with the asset type
     * @param {string} domain - Filter results by organization using its domain
     * @param {string} organizationId - Filter results by organizations. For more than one organization, & organizationId=1& organizationId=2, etc...
     * @param {string} runtimeVersion - Filters results by runtime version, allowing partial versions. For example '3.x' will filter in the range [3.0, 4.0)
     * @param {number} offset - The offset specifies the offset of the first row to return
     * @param {number} limit - Amount of objects retrieved in the response
    */
    post(query?: {
      search: string,
      type: string,
      domain: string,
      organizationId: string,
      runtimeVersion: string,
      offset: number,
      limit: number
    }, options?: { proxy: string, beforeSend: () => void, headers: object, body: object, baseUriParameters: object }): any;
    /**
     * Get a paginated set of assets
     *
     * @param {string} search - Filter results that partially match the input with the asset name
     * @param {string} type - Filter results that matches the input with the asset type
     * @param {string} domain - Filter results by organization using its domain
     * @param {string} organizationId - Filter results by organizations. For more than one organization, & organizationId=1& organizationId=2, etc...
     * @param {string} runtimeVersion - Filters results by runtime version, allowing partial versions. For example '3.x' will filter in the range [3.0, 4.0)
     * @param {number} offset - The offset specifies the offset of the first row to return
     * @param {number} limit - Amount of objects retrieved in the response
    */
    get(query?: {
      search: string,
      type: string,
      domain: string,
      organizationId: string,
      runtimeVersion: string,
      offset: number,
      limit: number
    }, options?: { proxy: string, beforeSend: () => void, headers: object, body: object, baseUriParameters: object }): any;
    groupId(groupId: string): {
      assetId(assetId: string): {
        get(query?: any, options?: any, async?: boolean): any;
        users: {
          get(query?: any, options?: any, async?: boolean): any;
          put(body?: any, options?: any, async?: boolean): any;
        };
        reviews: {
          search: {
            /**
             * Search for asset versions reviews
             *
             * @param {boolean} includeComments? - Include comments for reviews
            */
            post(query?: {
              includeComments: boolean
            }, options?: { proxy: string, beforeSend: () => void, headers: object, body: object, baseUriParameters: object }): any;
          };
        };
        productAPIVersion: {
          productAPIVersion(productAPIVersion: string): {
            get(query?: any, options?: any, async?: boolean): any;
          };
        };
        version(version: string): {
          get(query?: any, options?: any, async?: boolean): any;
          patch(body?: any, options?: any, async?: boolean): any;
          api: {
            json: {
              get(query?: any, options?: any, async?: boolean): any;
            };
          };
          pages: {
            get(query?: any, options?: any, async?: boolean): any;
            pagePath(pagePath: string): {
              get(query?: any, options?: any, async?: boolean): any;
            };
          };
          draft: {
            pages: {
              post(body?: any, options?: any, async?: boolean): any;
              get(query?: any, options?: any, async?: boolean): any;
              pagePath(pagePath: string): {
                put(body?: any, options?: any, async?: boolean): any;
                delete(body?: any, options?: any, async?: boolean): any;
                get(query?: any, options?: any, async?: boolean): any;
              };
            };
          };
          reviews: {
            /**
             * Get a list of reviews
             *
             * @param {boolean} includeComments? - Indicates to include comments or not in reviews
            */
            get(query?: {
              includeComments: boolean
            }, options?: { proxy: string, beforeSend: () => void, headers: object, body: object, baseUriParameters: object }): any;
            post(body?: any, options?: any, async?: boolean): any;
            reviewId(reviewId: string): {
              patch(body?: any, options?: any, async?: boolean): any;
              delete(body?: any, options?: any, async?: boolean): any;
              comments: {
                post(body?: any, options?: any, async?: boolean): any;
                commentId(commentId: string): {
                  patch(body?: any, options?: any, async?: boolean): any;
                  delete(body?: any, options?: any, async?: boolean): any;
                };
              };
            };
          };
          tags: {
            put(body?: any, options?: any, async?: boolean): any;
          };
        };
      };
    };
  };
};
